pub struct LineString {
pub points: Vec<Point>,
}Fields
points: Vec<Point>Trait Implementations
Sourceimpl<'a> AsEwkbLineString<'a> for LineString
impl<'a> AsEwkbLineString<'a> for LineString
Sourceimpl Clone for LineString
impl Clone for LineString
Sourcefn clone(&self) -> LineString
fn clone(&self) -> LineString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LineString
impl Debug for LineString
Sourceimpl FromSql<'_> for LineString
impl FromSql<'_> for LineString
Sourcefn accepts(ty: &Type) -> bool
fn accepts(ty: &Type) -> bool
Determines if a value of this type can be created from the specified
Postgres
Type.Sourcefn from_sql(ty: &Type, raw: &[u8]) -> Result<Self, Box<dyn Error + Sync + Send>>
fn from_sql(ty: &Type, raw: &[u8]) -> Result<Self, Box<dyn Error + Sync + Send>>
Creates a new value of this type from a buffer of data of the specified
Postgres
Type in its binary format. Read moreSourceimpl<'a> LineString<'a> for LineString
impl<'a> LineString<'a> for LineString
Sourceimpl PartialEq for LineString
impl PartialEq for LineString
Sourceimpl TwkbGeom for LineString
impl TwkbGeom for LineString
impl StructuralPartialEq for LineString